@@ -80,7 +80,7 @@ def get_registry_details(i):
 def check_x_total_value_update_dict(check_func, p, url="", headers={}, value_column_name="DEFAULT_VALUE", over_column_name="DEFAULT_COLUMN_NAME", results={}):
     flag = False
     if resp := gl_api.generate_get_request(host="", api="", token=headers.get("PRIVATE-TOKEN"), url=url): 
-        num = int(resp.headers.get('X-Total'))
+        num = int(resp.headers.get('X-Total', 0))
         num_over = check_func(num)
         if num_over:
             flag = True
@@ -150,3 +150,8 @@ def getVersion(host,token,api):
         result = resp.json()
         ## error handling - look for 200 
         return result
+
+def getArchivedProjectCount(host,token):
+    if resp := gl_api.generate_get_request(host=host,token=token,api='projects?archived=True'):
+        result = resp.headers.get('X-Total')
+        return result
\ No newline at end of file
